Installation
============

To install :mod:`audformat` run:

.. code-block:: bash

    $ # Create and activate Python virtual environment, e.g.
    $ # virtualenv --python=python3 ${HOME}/.envs/audformat
    $ # source ${HOME}/.envs/audformat/bin/activate
    $ pip install audformat
